Update your application's privacy policy to explicitly state that gender identity information is collected. Clearly describe the purposes for its collection, how it is used, processed, stored, and the data retention period. Ensure users are provided with transparent information, appropriate consent mechanisms are in place if required, and that collection practices comply with applicable data protection laws for sensitive information.